[![Build Status](https://travis-ci.org/wesleybeckner/decklizer.svg?branch=master)](https://travis-ci.org/wesleybeckner/decklizer)
[![Coverage Status](https://coveralls.io/repos/github/wesleybeckner/decklizer/badge.svg?branch=master)](https://coveralls.io/github/wesleybeckner/decklizer?branch=master)
[![PyPI version](https://badge.fury.io/py/decklizer.svg)](https://badge.fury.io/py/decklizer)

# Decklizer

Decklizer is a python library containing a column generation/knapsack solution to stock cutting.

## Installation

`pip install decklizer`
